@@ -2,7 +2,7 @@
 `%||%` <- function(l, r) if (is.null(l)) r else l
 
 str_trim <- function(x) {
-  sub("^\\s+", "", sub("\\s+$", "", x))
+  sub("^\\s+", "", sub("\\s+$", "", x, useBytes = TRUE), useBytes = TRUE)
 }
 
 str_squish <- function(x) {
@@ -105,14 +105,8 @@ postprocess_trailing_ws <- function(file, notws) {
   writeLines(lines, file)
 }
 
-# We both import and qualify, this is not a mistake.
-# We import for work around a jetpack revdep failure.
-# We qualify to make desc work in (patched) pkgload
-
-#' @importFrom rprojroot find_root
-
 find_description <- function(dir) {
-  pkg_root <- rprojroot::find_root(rprojroot::is_r_package, dir)
+  pkg_root <- find_package_root(dir)
   file.path(pkg_root, "DESCRIPTION")
 }
 
@@ -191,3 +185,16 @@ desc_message <- function(...) {
   message(msg)
 
 }
+
+write_dcf <- function(...) {
+  if (getRversion() >= "3.5.0") {
+    write.dcf(..., useBytes = TRUE)
+  } else {
+    write.dcf(...)
+  }
+}
+
+mkdirp <- function(dir) {
+  s <- vapply(dir, dir.create, logical(1), recursive = TRUE, showWarnings = FALSE)
+  invisible(s)
+}
\ No newline at end of file
