@@ -1,14 +1,14 @@
 
 test_package_root <- function() {
   x <- tryCatch(
-    rprojroot::find_package_root_file(),
+    find_package_root(),
     error = function(e) NULL)
 
   if (!is.null(x)) return(x)
 
   pkg <- testthat::testing_package()
   x <- tryCatch(
-    rprojroot::find_package_root_file(
+    find_package_root(
       path = file.path("..", "..", "00_pkg_src", pkg)),
     error = function(e) NULL)
 
