@@ -5,7 +5,7 @@ test_that("str orders fields", {
   desc$del("Package")
   desc$set("Package", "foobar")
 
-  expect_match(crayon::strip_style(desc$str()), "^Package:")
+  expect_match(cli::ansi_strip(desc$str()), "^Package:")
 })
 
 test_that("str formats some fields specially", {
@@ -13,29 +13,29 @@ test_that("str formats some fields specially", {
 
   desc$set("Imports", "pkg1, pkg2, \n pkg3, pkg4")
   expect_match(
-    crayon::strip_style(desc$str()),
+    cli::ansi_strip(desc$str()),
     "Imports:\n    pkg1,\n    pkg2,\n    pkg3,\n    pkg4"
   )
 
   desc$set("Collate", "file1.R 'file2.R' 'file with spaces.R' file4.R")
   expect_match(
-    crayon::strip_style(desc$str()),
+    cli::ansi_strip(desc$str()),
     "Collate:\n    'file1.R'\n    'file2.R'\n    'file with spaces.R'\n    'file4.R'"
   )
 })
 
 test_that("str formats authors properly", {
 
-  desc <- description$new("D2")
+  desc <- description$new(test_path("D2"))
 
   expect_snapshot(
-    cat(crayon::strip_style(desc$str(by_field = TRUE)[["Authors@R"]]))
+    cat(cli::ansi_strip(desc$str(by_field = TRUE)[["Authors@R"]]))
   )
 })
 
 test_that("authors are printed to the screen properly", {
 
-  desc <- description$new("D2")
+  desc <- description$new(test_path("D2"))
 
   expect_output(
     print(desc),
@@ -50,7 +50,7 @@ test_that("authors are printed to the screen properly", {
 })
 
 test_that("continuation lines", {
-  desc <- description$new("D7")
+  desc <- description$new(test_path("D7"))
   t1 <- desc$str(normalize = TRUE)
   t2 <- desc$str(normalize = FALSE)
   expect_false(grepl("\n[ \t]*\n", t1))
